@@ -4,11 +4,12 @@ try:
     import open3d as o3d
     from ._artists import (Artist, Line3D, PointCollection3D, Vector3D, Frame,
                            Trajectory, Camera, Box, Sphere, Cylinder, Mesh,
-                           Ellipsoid, Capsule, Cone, Graph)
+                           Ellipsoid, Capsule, Cone, Plane, Graph)
     from ._figure import figure, Figure
 
     __all__ = ["figure", "Figure", "Artist", "Line3D", "PointCollection3D",
                "Vector3D", "Frame", "Trajectory", "Camera", "Box", "Sphere",
-               "Cylinder", "Mesh", "Ellipsoid", "Capsule", "Cone", "Graph"]
+               "Cylinder", "Mesh", "Ellipsoid", "Capsule", "Cone", "Plane",
+               "Graph"]
 except ImportError:
     warnings.warn("3D visualizer is not available. Install open3d.")
